@@ -24,7 +24,7 @@ class BI(object):
     def process_bi(self):
         self.open_database_connections()
 
-        self.products_df = self.utils.get_dataframe_from_mongo(self.mongo_conn)
+        self.products_df = self.utils.get_dataframe_from_mongo(self.mongo_conn, 'food_df')
 
         self.close_mongo_connection()
 
