@@ -5,10 +5,13 @@ sys.path.insert(0, os.path.join(os.path.dirname(__file__), '../../'))
 import tensorflow_datasets as tfds
 import pickle
 import numpy as np
+import gdown
+import pkg_resources
+from symspellpy import SymSpell, Verbosity
 
 from utils import utils
 from nkia.ml.cnn_nlp_model import CNN
-import pkg_resources
+
 
 class classifyProducts(object):
 
@@ -31,7 +34,14 @@ class classifyProducts(object):
         cnn.load_weights('./'+model_name+'/'+model_version+'/model_checkpoint/cp.ckpt').expect_partial()
         return cnn
 
-    def inference_from_category_model(self, model, product_name=[''], description=['']): 
+    def load_dictionary(self):
+        if 'nlp_dictionary' not in os.listdir():
+            os.makedirs('nlp_dictionary')
+            gdown.download('https://project-elements-nk.s3.amazonaws.com/dictionary.txt', 'nlp_dictionary/dictionary.txt', quiet=False)        
+
+        return utils.instantiate_spelling_corrector('nlp_dictionary/dictionary.txt')
+
+    def inference_from_category_model(self, model, sym_spell, product_name=[''], description=['']): 
         """
         This method is responsible to infer the product category based on your caracteristics. Pass just one product
         by time.
@@ -44,7 +54,7 @@ class classifyProducts(object):
             str: Category name. e.g: 'Bebidas não alcoolicas'
 
         """     
-        X = self.preprocessing_fn(product_name, description, './category_model')
+        X = self.preprocessing_fn(sym_spell, product_name, description, './category_model')
 
         product_category = model(np.array(X), training=False).numpy()[0]
         product_category_proba = product_category[product_category.argmax()]
@@ -54,7 +64,7 @@ class classifyProducts(object):
 
         return self.label_encoder.inverse_transform([product_category.argmax()])[0]
 
-    def inference_from_food_model(self, model, product_name=[''], description=['']):
+    def inference_from_food_model(self, model, sym_spell, product_name=[''], description=['']):
         """
         This method is responsible to infer if a product is a food or not. Pass just one product
         by time.
@@ -66,19 +76,18 @@ class classifyProducts(object):
             str: food or not food.
 
         """     
-        X = self.preprocessing_fn(product_name, description, './food_model')
+        X = self.preprocessing_fn(sym_spell, product_name, description, './food_model')
 
         product_type = model(np.array(X), training=False).numpy()
         product_type = 1 if product_type > 0.5 else 0
 
         return self.label_encoder.inverse_transform([product_type])[0] 
 
-    def preprocessing_fn(self, product_name, description, model_name):       
+    def preprocessing_fn(self, sym_spell, product_name, description, model_name):       
         model_version = pkg_resources.get_distribution('nkia').version
-        tokenizer = tfds.features.text.SubwordTextEncoder.load_from_file(
-            './'+model_name+'/'+model_version+'/token')
+        tokenizer = tfds.features.text.SubwordTextEncoder.load_from_file(model_name+'/'+model_version+'/token')
 
-        X = utils.get_cleaned_predictor([description], [product_name])
+        X = utils.get_cleaned_predictor(sym_spell, [description], [product_name])
 
         tokenized_predictor = [tokenizer.encode(sentence) for sentence in X] 
 
