@@ -27,7 +27,7 @@ class trainProductsModel(object):
     def __init__(self, model_to_train, show_confusion_matrix=False):
         self.model_to_train = model_to_train
         self.confusion_matrix = show_confusion_matrix
-        self.new_model_path, self.last_model_path = self.create_saved_model_folder(model_to_train)
+        self.new_model_path, self.last_model_path = self.create_saved_model_folder(self.model_to_train)
         self.train_model()
 
     def create_saved_model_folder(self, model_name):
@@ -74,12 +74,12 @@ class trainProductsModel(object):
         cp_callback = tf.keras.callbacks.ModelCheckpoint(filepath=self.new_model_path + '/model_checkpoint/cp.ckpt',
                                                         save_weights_only=True,
                                                         verbose=1)
-        cnn.fit(X_train, y_train,
-                batch_size = 64,
-                epochs = 5,
-                verbose = 1,
-                validation_split = 0.10,
-                callbacks=[cp_callback])
+        # cnn.fit(X_train, y_train,
+        #         batch_size = 64,
+        #         epochs = 2,
+        #         verbose = 1,
+        #         validation_split = 0.10,
+        #         callbacks=[cp_callback])
 
         self.evaluate_and_deploy_model(cnn, X_test, y_test, y)
         
@@ -88,9 +88,11 @@ class trainProductsModel(object):
 
     def get_data(self):
         collection = 'food_df' if self.model_to_train == 'category_model' else 'not_food_df'
-        self.open_mongo_connections()
-        dataframe = utils.get_dataframe_from_mongo(self.mongo_conn, collection)
-        self.close_mongo_connection()
+        # self.open_mongo_connections()
+        # dataframe = utils.get_dataframe_from_mongo(self.mongo_conn, collection)
+        # self.close_mongo_connection()
+        import pandas as pd
+        dataframe = pd.read_excel('/home/alvaro/Área de Trabalho/servicos-biodigital/src/utils/datasets/positive_and_negative_food.xlsx')
         
         dataframe['description'].fillna('', inplace=True)
 
@@ -150,9 +152,9 @@ class trainProductsModel(object):
             self.last_model_path, X_test, y_test, y)
 
         if new_model_f1 >= last_model_f1 and (new_model_accuracy - last_model_accuracy) >= -1:
+            self.create_and_deploy_tarfile([self.new_model_path + '.tar.gz'], self.new_model_path)
             shutil.rmtree(self.last_model_path)
             utils.read_file(os.getcwd() + '/config.txt', model_version)
-            self.create_and_deploy_tarfile(self.new_model_path + '.tar.gz', self.new_model_path)
             subprocess.call(os.getcwd() + '/pypi-upload.sh')
         else: 
             shutil.rmtree(self.new_model_path)
@@ -166,13 +168,6 @@ class trainProductsModel(object):
         last_cnn.compile(loss=self.loss_f, optimizer='adam', metrics=['accuracy'])
         return self.evaluate_model(last_cnn, X_test, y_test)
 
-    def create_and_deploy_tarfile(self, output_filename, source_dir):
-        with tarfile.open(output_filename, "w:gz") as tar:
-            tar.add(source_dir, arcname=os.path.basename(source_dir))
-
-        DeployModel().deploy_to_s3(self.new_model_path + '.tar.gz')
-        os.remove(self.new_model_path + '.tar.gz')
-
     def evaluate_model(self, model, X_test, y_test):
         y_pred_test = model.predict(X_test)
         predicted = [result.argmax() for result in y_pred_test]
@@ -185,6 +180,25 @@ class trainProductsModel(object):
 
         return accuracy, f_score
 
+    def create_and_deploy_tarfile(self, output_filename, source_dir):
+        output_filename = self.standardize_model_version(output_filename)
+
+        for output in output_filename:
+            with tarfile.open(output, "w:gz") as tar:
+                tar.add(source_dir, arcname=os.path.basename(source_dir))
+
+            DeployModel().deploy_to_s3(output)
+            os.remove(output)
+
+    def standardize_model_version(self, output_filename):
+        another_model_name = 'food_model' if self.model_to_train == 'category_model' else 'category_model'   
+        another_model_path = self.new_model_path.replace(self.model_to_train, another_model_name)
+        path = '/'.join(another_model_path.split('/')[0:-1])
+        os.rename(path +'/'+ os.listdir(path)[0], another_model_path)
+        
+        output_filename.append(another_model_path)
+        return output_filename
+
     def predict_and_plot_matrix(self, model, X, y):
         y_pred_test = model.predict(X)
         predicted = [result.argmax() for result in y_pred_test]
@@ -196,4 +210,4 @@ class trainProductsModel(object):
         sns.heatmap(cm, annot=True)
         plt.show()
 
-trainProductsModel(argv[1] if len(argv) > 1 else 'category_model')
+trainProductsModel(argv[1] if len(argv) > 1 else 'food_model')
