@@ -24,7 +24,7 @@ def get_cleaned_predictor(sym_spell, description, product_name):
 
     X = join_all_predictors(description, product_name)
 
-    X = correct_word_spelling(sym_spell, X)
+    # X = correct_word_spelling(sym_spell, X)
     return X
 
 def get_description_and_name(data):    
@@ -101,17 +101,14 @@ def download_model(url, output):
     tar.close()
     os.remove(output)
 
-def instantiate_spelling_corrector():
+def instantiate_spelling_corrector(dict_path='./src/utils/datasets/dictionary.txt'):
     sym_spell = SymSpell(max_dictionary_edit_distance=2, prefix_length=7)
-
-    sym_spell.load_dictionary('./src/utils/datasets/dictionary.txt', term_index=0, count_index=1)
-    sym_spell.load_bigram_dictionary('./src/utils/datasets/word_bigram.txt', 0, 2)
+    sym_spell.load_dictionary(dict_path, term_index=0, count_index=1)
 
     return sym_spell
 
 def correct_word_spelling(sym_spell, corpus):
     final_corpus = []
-    print('Correcting word spelling')
     for phrase in corpus:
         new_phrase = []
         for input_term in phrase.split():
